cmd

package
v0.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: MPL-2.0 Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

func Namespace

func Namespace() string

Namespace returns the currently configured namespace from the flag

func SetVersion

func SetVersion(v string)

SetVersion sets the version string on the root command. Called from main with the value injected via ldflags.

Types

This section is empty.

Directories

Path Synopsis
Package roles implements `warden role`, the agent-facing role-introspection command group.
Package roles implements `warden role`, the agent-facing role-introspection command group.
Package schema implements `warden schema`, the agent-facing introspection command.
Package schema implements `warden schema`, the agent-facing introspection command.
Package skills groups the CLI subcommands for the global agent skill registry exposed at /v1/sys/skills.
Package skills groups the CLI subcommands for the global agent skill registry exposed at /v1/sys/skills.

Jump to