Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Namespace ¶
func Namespace() string
Namespace returns the currently configured namespace from the flag
func SetVersion ¶
func SetVersion(v string)
SetVersion sets the version string on the root command. Called from main with the value injected via ldflags.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package roles implements `warden role`, the agent-facing role-introspection command group.
|
Package roles implements `warden role`, the agent-facing role-introspection command group. |
|
Package schema implements `warden schema`, the agent-facing introspection command.
|
Package schema implements `warden schema`, the agent-facing introspection command. |
|
Package skills groups the CLI subcommands for the global agent skill registry exposed at /v1/sys/skills.
|
Package skills groups the CLI subcommands for the global agent skill registry exposed at /v1/sys/skills. |
Click to show internal directories.
Click to hide internal directories.